package com.yanzhu.jh.trouble.mapper;

import java.util.List;
import com.yanzhu.jh.trouble.domain.SmzSspMarks;

/**
 * 质量留痕Mapper接口
 * 
 * @author JiangYuQi
 * @date 2023-07-28
 */
public interface SmzSspMarksMapper 
{
    /**
     * 查询质量留痕
     * 
     * @param id 质量留痕主键
     * @return 质量留痕
     */
    public SmzSspMarks selectSmzSspMarksById(String id);

    /**
     * 查询质量留痕列表
     * 
     * @param smzSspMarks 质量留痕
     * @return 质量留痕集合
     */
    public List<SmzSspMarks> selectSmzSspMarksList(SmzSspMarks smzSspMarks);

    /**
     * 新增质量留痕
     * 
     * @param smzSspMarks 质量留痕
     * @return 结果
     */
    public int insertSmzSspMarks(SmzSspMarks smzSspMarks);

    /**
     * 修改质量留痕
     * 
     * @param smzSspMarks 质量留痕
     * @return 结果
     */
    public int updateSmzSspMarks(SmzSspMarks smzSspMarks);

    /**
     * 删除质量留痕
     * 
     * @param id 质量留痕主键
     * @return 结果
     */
    public int deleteSmzSspMarksById(String id);

    /**
     * 批量删除质量留痕
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSmzSspMarksByIds(String[] ids);
}
